;; Generated package description from gnome-dark-style.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "gnome-dark-style" "0.2.1.0.20250308.192802" "Sync theme with GNOME color-scheme" '((emacs "30.1")) :commit "2d6bf27ee19d749c538778dc97b70b7fc521aa23" :authors '(("David Dimagid" . "davidimagid@gmail.com")) :maintainer '("David Dimagid" . "davidimagid@gmail.com") :keywords '("themes" "gnome" "sync" "dark" "light" "color-scheme") :url "https://github.com/dimagid/gnome-dark-style")
